/***************************************************************
 * Name:      checklist.cpp
 * Purpose:   Code for Dialog spinControl
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-09
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "checklist.h"

IMPLEMENT_DYNAMIC_CLASS( clValidator, wxValidator )
BEGIN_EVENT_TABLE( clValidator, wxValidator )
END_EVENT_TABLE()

clValidator::clValidator(std::vector<bool> *v) : wxValidator(), m_valores(v) {}

bool clValidator::TransferFromWindow()
{
    try {
        wxCheckListBox *clb = dynamic_cast<wxCheckListBox*>(m_validatorWindow);
        for(size_t i=0; i<m_valores->size(); i++)
            m_valores->at(i) = clb->IsChecked(i);
    }
    catch (...) {
        wxFAIL_MSG( _T("clValidator sólo funciona con wxCheckListBox"));
        return false;
    }
    return true;
}

bool clValidator::TransferToWindow()
{
    try {
        wxCheckListBox *clb = dynamic_cast<wxCheckListBox*>(m_validatorWindow);
        for(size_t i=0; i<m_valores->size(); i++) {
            clb->Check(i, m_valores->at(i));
        }
    }
    catch(...) {
        wxFAIL_MSG( _T("clValidator sólo funciona con wxCheckListBox"));
        return false;
    }
    return true;
}

bool clValidator::Validate(wxWindow* parent)
{
//    if (!m_validatorWindow->IsEnabled()) return true;
    return true;
}


wxBEGIN_EVENT_TABLE(checklist, wxDialog)
    EVT_CLOSE(checklist::OnClose)
    EVT_CHECKLISTBOX(idCheckList, OnChecklist)
wxEND_EVENT_TABLE()

checklist::checklist(wxWindow *wnd, datosCheckList &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de checkboxes")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    wxString cads[] = {
        _T("Opción 1"),
        _T("Opción 2"),
        _T("Opción 3"),
        _T("Opción 4")
    };

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_checkListBox = new wxCheckListBox(this, idCheckList, wxDefaultPosition, wxSize(200, wxDefaultCoord), sizeof(cads)/sizeof(cads[0]), cads, 0, clValidator(&data.check));
    boxHorizontal->Add(m_checkListBox, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

checklist::~checklist()
{
    //dtor
}

void checklist::OnClose(wxCloseEvent& event) {
    Destroy();
}

void checklist::OnChecklist(wxCommandEvent& event) {

    int indice = event.GetInt();
    bool estado = m_checkListBox->IsChecked(indice);
    wxString cad;
    cad << _T("Indice: ") << indice << _T(" ") << (estado ? _T("marcado") : _T("no marcado"));
    wxMessageBox(cad, _T("Respuesta"));
}

