/***************************************************************
 * Name:      radiobutton.cpp
 * Purpose:   Code for Dialog radioButton
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-11
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "radiobutton.h"

IMPLEMENT_DYNAMIC_CLASS( rbValidator, wxValidator )
BEGIN_EVENT_TABLE( rbValidator, wxValidator )
END_EVENT_TABLE()

rbValidator::rbValidator(int *v) : wxValidator(), m_opcion(v) {}

bool rbValidator::TransferFromWindow()
{
    try {
        wxRadioButton *crb = dynamic_cast<wxRadioButton*>(m_validatorWindow);
        if(crb->GetValue()) {
            wxRadioButton *primero = crb->GetFirstInGroup();
            *m_opcion = crb->GetId()-primero->GetId();
        }
    }
    catch (...) {
        wxFAIL_MSG( _T("rbValidator sólo funciona con wxRadioButton"));
        return false;
    }
    return true;
}

bool rbValidator::TransferToWindow()
{
    try {
        wxRadioButton *crb = dynamic_cast<wxRadioButton*>(m_validatorWindow);
        wxRadioButton *primero = crb->GetFirstInGroup();
        if(crb->GetId()-primero->GetId() == *m_opcion) crb->SetValue(true);
    }
    catch(...) {
        wxFAIL_MSG( _T("rbValidator sólo funciona con wxRadioButton"));
        return false;
    }
    return true;
}

bool rbValidator::Validate(wxWindow* parent)
{
    return true;
}


wxBEGIN_EVENT_TABLE(radioButton, wxDialog)
    EVT_CLOSE(radioButton::OnClose)
    EVT_BUTTON(wxID_OK, radioButton::OnOk)
wxEND_EVENT_TABLE()

radioButton::radioButton(wxWindow *wnd, datosRadioButton &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de radio buttons")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxString cads[] = {
        _T("Opción 1"),
        _T("Opción 2"),
        _T("Opción 3"),
        _T("Opción 4")
    };

    boxVertical = new wxBoxSizer(wxVERTICAL);
    rbValidator validator(&data.opcion);

    m_radioButton = new wxRadioButton(this, idRadioButton, cads[0], wxDefaultPosition, wxSize(200, wxDefaultCoord), wxRB_GROUP); //, validator);
    Connect(idRadioButton, wxEVT_RADIOBUTTON, (wxObjectEventFunction)&radioButton::OnRadioButton);
    boxVertical->Add(m_radioButton, wxSizerFlags().Border());
    for(size_t i = 1; i<sizeof(cads)/sizeof(cads[0]); i++) {
        m_radioButton = new wxRadioButton(this, idRadioButton+i, cads[i], wxDefaultPosition, wxSize(200, wxDefaultCoord), 0); //, validator);
        Connect(idRadioButton+i, wxEVT_RADIOBUTTON, (wxObjectEventFunction)&radioButton::OnRadioButton);
        boxVertical->Add(m_radioButton, wxSizerFlags().Border());
    }

    wxRadioButton* activo = (wxRadioButton*)wxWindow::FindWindowById(idRadioButton+data.opcion, this);
    activo->SetValue(true);

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

radioButton::~radioButton()
{
    //dtor
}

void radioButton::OnClose(wxCloseEvent& event) {
    Destroy();
}

void radioButton::OnRadioButton(wxCommandEvent& event) {
    int sel = event.GetId();
    wxString cad;
    cad << _T("Opción: ") << sel - idRadioButton + 1;
    wxMessageBox(cad, _T("Seleccionada"));
}

void radioButton::OnOk(wxCommandEvent& event) {
     wxRadioButton* activo = (wxRadioButton*)wxWindow::FindWindowById(idRadioButton, this);
     while(activo && !activo->GetValue()) activo = activo->GetNextInGroup();
     data.opcion = activo->GetId()-idRadioButton;
     EndModal(wxID_OK);
}
