/***************************************************************
 * Name:      wx007Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-11-09
 * Copyright: Salvador Pozo (www.conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx007Main.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx007Frame, wxFrame)
    EVT_CLOSE(wx007Frame::OnClose)
    EVT_MENU(idMenuQuit, wx007Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx007Frame::OnAbout)
    EVT_MENU(idMenuCheckBox, wx007Frame::OnCheckBox)
    EVT_MENU(idMenuCheckList, wx007Frame::OnCheckList)
    EVT_MENU(idMenuToggleButton, wx007Frame::OnToggleButton)
    EVT_MENU(idMenuRadioButton, wx007Frame::OnRadioButton)
    EVT_MENU(idMenuRadioBox, wx007Frame::OnRadioBox)
END_EVENT_TABLE()

wx007Frame::wx007Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title),
      data(false, wxCHK_UNCHECKED, wxCHK_UNCHECKED),
      lista((std::vector<bool>){true, false, true, false}),
      toggle(false),
      radio(2),
      radiobox(3)
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuCheckBox, _T("&CheckBox"), _T("Ejemplo de checkboxes"));
    fileMenu->Append(idMenuCheckList, _T("&CheckList"), _T("Ejemplo de check list"));
    fileMenu->Append(idMenuToggleButton, _T("&ToggleButton"), _T("Ejemplo de toggle button"));
    fileMenu->Append(idMenuRadioButton, _T("&RadioButton"), _T("Ejemplo de radio button"));
    fileMenu->Append(idMenuRadioBox, _("&RadioBox"), _T("Ejemplo de radiobox"));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Cerrar la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre\tF1"), _T("Muestra información sobre esta aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_T("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);

}


wx007Frame::~wx007Frame()
{
}

void wx007Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx007Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx007Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _T("Bienvenido a..."));
}

wxString wx007Frame::Estado(wxCheckBoxState estado) {
    switch(estado) {
        case wxCHK_UNCHECKED: return _T("no marcado");
        case wxCHK_CHECKED: return _T("marcado");
        default: return _T("indeterminado");
    }
}

void wx007Frame::OnCheckBox(wxCommandEvent& event) {
    wxString cad;
    checkBoxes *dlg = new checkBoxes(this, data);
    dlg->ShowModal();

    cad << _T("Check 1: ") << (data.check1 ? _T("marcado") : _T("no marcado")) << "\n";
    cad << _T("Check 3: ") << Estado(data.check3) << "\n";
    cad << _T("Check 4: ") << Estado(data.check4) << "\n";

    wxMessageBox(cad, _T("Respuesta"));
}

void wx007Frame::OnCheckList(wxCommandEvent& event) {
    wxString cad;
    checklist *dlg = new checklist(this, lista);
    dlg->ShowModal();

    cad << _T("Check 1: ") << (lista.check[0] ? _T("marcado") : _T("no marcado")) << "\n";
    cad << _T("Check 2: ") << (lista.check[1] ? _T("marcado") : _T("no marcado")) << "\n";
    cad << _T("Check 3: ") << (lista.check[2] ? _T("marcado") : _T("no marcado")) << "\n";
    cad << _T("Check 4: ") << (lista.check[3] ? _T("marcado") : _T("no marcado")) << "\n";

    wxMessageBox(cad, _T("Respuesta"));
}

void wx007Frame::OnToggleButton(wxCommandEvent& event) {
    wxString cad;
    toggleButton *dlg = new toggleButton(this, toggle);
    dlg->ShowModal();
}

void wx007Frame::OnRadioButton(wxCommandEvent& event) {
    wxString cad;
    radioButton *dlg = new radioButton(this, radio);
    dlg->ShowModal();

    cad << _T("Radio: ") << radio.opcion+1 << "\n";

    wxMessageBox(cad, _T("Respuesta"));
}

void wx007Frame::OnRadioBox(wxCommandEvent& event) {
    wxString cad;
    radioBox *dlg = new radioBox(this, radiobox);
    dlg->ShowModal();

    cad << _T("Radio: ") << radiobox.opcion+1 << "\n";

    wxMessageBox(cad, _T("Respuesta"));}
